/* SQL DDL: Create an implementation of the model using the SQL Data Definition Language */
/*  Note: You may want to change some field types to improve the implementation on your DBMS */
/*   Comments such as this may not be supported by your system and may have to be removed *//*   PostgreSQL: You should create the entire database as Unicode!  */



/*=== Table: CollectingPerson ===*/
/* Persons or groups involved in collecting a single specimen. */
  /*   CollectionSpecimenID: Refers to ID of CollectionSpecimen (= foreign key). */
  /*   CollectorsName: Name of the collecting person or group, e.g. "Miller, W.". */
  /*   CollectorsNumber: Number assigned by the collector during the collection. */
  /*   CollectorsSequence: Automatically set during entrance of the data to maintain the sequence of the collectors. */
CREATE TABLE "CollectingPerson"
 ( 
    "CollectionSpecimenID"  	 int4              	 NOT NULL,
    "CollectorsName"  	 varchar( 255 )     	 NOT NULL,
    "CollectorsNumber"  	 varchar( 255 )     	 NULL,
    "CollectorsSequence"  	 timestamp         	 NOT NULL DEFAULT now(),
  PRIMARY KEY ( "CollectionSpecimenID","CollectorsName" )
 );




/*=== Table: CollectionDuplicate ===*/
/* Collection specimen stored in other collections. */
  /*   CollectionSpecimenID: Refers to ID of CollectionSpecimen (= foreign key). */
  /*   AccessionNumber: Accession number of the collection, e.g. "M-3890492". */
  /*   CollectionName: Name of the collection where the duplicate specimen is deposed. */
  /*   Notes: User defined notes. */
CREATE TABLE "CollectionDuplicate"
 ( 
    "CollectionSpecimenID"  	 int4              	 NOT NULL,
    "AccessionNumber"  	 varchar( 255 )     	 NOT NULL,
    "CollectionName"  	 varchar( 255 )     	 NULL,
    "Notes"  	 varchar( 255 )     	 NULL,
  PRIMARY KEY ( "CollectionSpecimenID","AccessionNumber" )
 );




/*=== Table: CollectionGeography ===*/
/* Geographical data of the locality where the specimen were collected. */
  /*   CollectionSpecimenID: Refers to ID of CollectionSpecimen (= foreign key). */
  /*   LocalisationSystemID: Refers to ID of LocationIdentification (= foreign key). */
  /*   Location1: Either a named location selected from a thesaurus (e.g."Germany, Bavaria, Kleindingharting") or values e.g. 100 - 200 m (for altitude range). */
  /*   Location2: Corresponding value to Location2 or ID of Thesaurus. */
  /*   DeterminationDate: Date of the determination of the geography. */
  /*   Responsible: Person, team or organisation responsible for the data. */
  /*   AverageAltitudeCache: Calculated altitude as parsed from the location fields. */
  /*   AverageLongitudeCache: Calculated longitude as parsed from the location fields. */
  /*   AverageLatitudeCache: Calculated latitude as parsed from the location fields. */
CREATE TABLE "CollectionGeography"
 ( 
    "CollectionSpecimenID"  	 int4              	 NOT NULL,
    "LocalisationSystemID"  	 int4              	 NOT NULL,
    "Location1"  	 varchar( 255 )     	 NULL,
    "Location2"  	 varchar( 255 )     	 NULL,
    "DeterminationDate"  	 timestamp         	 NULL,
    "Responsible"  	 varchar( 255 )     	 NULL,
    "AverageAltitudeCache"  	 float8            	 NULL,
    "AverageLongitudeCache"  	 float8            	 NULL,
    "AverageLatitudeCache"  	 float8            	 NULL,
  PRIMARY KEY ( "CollectionSpecimenID","LocalisationSystemID" )
 );




/*=== Table: CollectionImage ===*/
/* Images of the collection specimen. */
  /*   CollectionSpecimenID: Refers to ID of CollectionSpecimen (= foreign key). */
  /*   ImagePath: The file name and path of the image underneath the main folder for all images e.g. "/Images/Fungi/Ascomycetes/Erysiphales/ErysipheGraminis.jpg". */
  /*   IdentificationUnitID: Only given if image refers to a single Unit of  CollectionSpecimen, refers to ID of IdentificationUnit (= foreign key). */
  /*   ResourceGroup: Link to ResourceGroup, defining copyright, scan resolution, scale (if identical for all images), etc. */
  /*   Responsible: Person responsible for the image. */
  /*   Notes: Notes concerning the image, e.g. scale, resolution. See CollectionProject for additional information. */
CREATE TABLE "CollectionImage"
 ( 
    "CollectionSpecimenID"  	 int4              	 NOT NULL,
    "ImagePath"  	 varchar( 255 )     	 NOT NULL,
    "IdentificationUnitID"  	 int4              	 NULL,
    "ResourceGroup"  	 varchar( 255 )     	 NULL,
    "Responsible"  	 varchar( 255 )     	 NULL,
    "Notes"  	 varchar( 255 )     	 NULL,
  PRIMARY KEY ( "CollectionSpecimenID","ImagePath" )
 );




/*=== Table: CollectionLookup ===*/
/* Data for lookup queries. */
  /*   Parameter: Name of the parameter, e.g. "TypeStatus". */
  /*   Value: Value of the parameter, e.g. "holotypus". */
  /*   Description: Description of the parameter. */
  /*   EnableEditing: If this item can be edited by the user. */
CREATE TABLE "CollectionLookup"
 ( 
    "Parameter"  	 varchar( 255 )     	 NOT NULL,
    "Value"  	 varchar( 255 )     	 NOT NULL,
    "Description"  	 varchar( 255 )     	 NULL,
    "EnableEditing"  	 bool              	 NULL,
  PRIMARY KEY ( "Parameter","Value" )
 );




/*=== Table: CollectionMaterial ===*/
/* Storage location and type of collection material of the specimen. */
  /*   CollectionSpecimenID: Refers to ID of CollectionSpecimen (= foreign key). */
  /*   MaterialCategory: Material e.g. "drawings", "slides" etc. */
  /*   StorageLocation: The place resp. taxon where the item is stored within the collection. */
CREATE TABLE "CollectionMaterial"
 ( 
    "CollectionSpecimenID"  	 int4              	 NOT NULL,
    "MaterialCategory"  	 varchar( 255 )     	 NOT NULL DEFAULT 'herbarium specimens',
    "StorageLocation"  	 varchar( 255 )     	 NULL,
  PRIMARY KEY ( "CollectionSpecimenID","MaterialCategory" )
 );




/*=== Table: CollectionProject ===*/
/* Projects as stored within the database DiversityUsers to which the collection specimen belongs to. */
  /*   CollectionSpecimenID: Refers to ID of CollectionSpecimen (= foreign key). */
  /*   DiversityProject: Project to which the specimen belongs to as stored in DiversityUsers. */
CREATE TABLE "CollectionProject"
 ( 
    "CollectionSpecimenID"  	 int4              	 NOT NULL,
    "DiversityProject"  	 varchar( 255 )     	 NOT NULL,
  PRIMARY KEY ( "CollectionSpecimenID","DiversityProject" )
 );




/*=== Table: CollectionSpecimen ===*/
/* Data of collection specimen. */
  /*   CollectionSpecimenID: Unique reference ID for the collection record (primary key). */
  /*   CollectionDate: Calculated date, based on CollectionDay, -Month and -Year. */
  /*   CollectionDay: The day of the collection event. */
  /*   CollectionMonth: The month of the collection event. */
  /*   CollectionYear: The year of the collection event. */
  /*   CollectionDateSupplement: Verbal or additional date information, e.g. "end of summer 1985". */
  /*   LocalityDescription: Locality and geo-ecological description of the locality as written on the original label. */
  /*   LabelTitle: Title of label if different from ExsiccataTitle for printing labels. Will be printed on label after ExsiccataTitle. */
  /*   LabelType: Whether the label is typed, typed with hand written comments of completely handwriting etc. */
  /*   LabelScanPath: The path and file name of the scan of the label underneath the folder where all labels are stored e.g. "/Fungi/Erysiphales/M-0010/M-001034.jpg". */
  /*   LabelTranscription: The state of the transcription of a label into the database: "Not started" / " incomplete" / "complete". */
  /*   LabelTranscriptionNotes: User defined notes concerning the transcription of the label into the database. */
  /*   AccessionNumber: Accession number of the specimen within the collection, e.g. "M-29834752". */
  /*   AccessionDate: The date, when the specimen was taken in the collection (format: YYYY/MM/DD). */
  /*   CollectionName: Name of the Collection, e.g. "Botanische Staatssammlung Mnchen". */
  /*   ExsiccataTitle: Standard abbreviation of the exsiccata. */
  /*   ExsiccataNumber: Number within the exsiccata. */
  /*   DepositorsName: The name of the depositor resp. the herbarium if not the original collector, e.g. "Herbarium P. Dbbler". */
  /*   DepositorsAccessionNumber: Accession number of the specimen within the herbarium where the specimen came from if not the original collection, e.g. "D-23948". */
  /*   OriginalNotes: Notes given by the collector, resp. found on the label. */
  /*   AdditionalNotes: Additional notes made by the editor. */
  /*   LoanInformation: Notes if the item is on loan resp. borrowed. */
  /*   Problems: Problems found with the specimen, e.g. doubtful identification, locality etc. */
  /*   PrintLabel: Is set true if the label should be printed, is set false if the label should not be printed. */
CREATE TABLE "CollectionSpecimen"
 ( 
    "CollectionSpecimenID" SERIAL   NOT NULL PRIMARY KEY,
    "CollectionDate"  	 timestamp         	 NULL,
    "CollectionDay"  	 int4              	 NULL,
    "CollectionMonth"  	 int4              	 NULL,
    "CollectionYear"  	 int4              	 NULL,
    "CollectionDateSupplement"  	 varchar( 255 )     	 NULL,
    "LocalityDescription"  	 varchar( 255 )     	 NULL,
    "LabelTitle"  	 varchar( 255 )     	 NULL,
    "LabelType"  	 varchar( 255 )     	 NULL,
    "LabelScanPath"  	 varchar( 255 )     	 NULL,
    "LabelTranscription"  	 varchar( 255 )     	 NULL,
    "LabelTranscriptionNotes"  	 varchar( 255 )     	 NULL,
    "AccessionNumber"  	 varchar( 255 )     	 NULL,
    "AccessionDate"  	 varchar( 255 )     	 NULL,
    "CollectionName"  	 varchar( 255 )     	 NULL,
    "ExsiccataTitle"  	 varchar( 255 )     	 NULL,
    "ExsiccataNumber"  	 varchar( 255 )     	 NULL,
    "DepositorsName"  	 varchar( 255 )     	 NULL,
    "DepositorsAccessionNumber"  	 varchar( 255 )     	 NULL,
    "OriginalNotes"  	 text              	 NULL,
    "AdditionalNotes"  	 text              	 NULL,
    "LoanInformation"  	 varchar( 255 )     	 NULL,
    "Problems"  	 varchar( 255 )     	 NULL,
    "PrintLabel"  	 bool              	 NULL DEFAULT 'true'
 );




/*=== Table: Identification ===*/
/* Identifications of the identification units. */
  /*   IdentificationUnitID: Refers to ID of CollectionUnit (= foreign key). */
  /*   CollectionSpecimenID: Refers to ID of CollectionSpecimen (= foreign key). */
  /*   IdentificationSequence: Date and time the identification was entered into the system, defines the ordering of identifications. */
  /*   IdentificationDay: The day of the identification event. */
  /*   IdentificationMonth: The month of the identification event. */
  /*   IdentificationYear: The year of the identification event. */
  /*   IdentificationDateSupplement: Verbal or additional identification date information, e.g. "end of summer 1985". */
  /*   VernacularName: Not taxonomic name e.g. limestone, conifer, hardwood. */
  /*   TaxonomicName: Valid name of the species with author names  of the  taxon e.g. "Rosa canina L.". */
  /*   NomID: Unique ID code of the taxon. Refers to the NomID code of TaxonomyName (= foreign key) in the database DiversityTaxonomy. */
  /*   IdentificationCategory: Category of the identification e.g. "determination"," confirmation", "absence". */
  /*   IdentificationQualifier: Qualification of the identification e.g. "cf."," aff.", "sp. nov.". */
  /*   IsLastName: Defines the valid name for the organism. Can be set only once per organism. */
  /*   LiteratureUsed: Source resp. literature used for the determination, e.g. "Schmeil-Fitschen 1995". */
  /*   Responsible: The person or institution responsible for the determination. */
  /*   Notes: User definded notes, e.g. the reason for the new determination / change of the name etc. */
  /*   IsExsiccataTaxon: Defines the name under which the collection specimen is published within an exsiccate. Can be set only once per collection specimen. */
CREATE TABLE "Identification"
 ( 
    "IdentificationUnitID"  	 int4              	 NOT NULL,
    "CollectionSpecimenID"  	 int4              	 NOT NULL,
    "IdentificationSequence"  	 timestamp         	 NOT NULL DEFAULT current_timestamp,
    "IdentificationDay"  	 int4              	 NULL,
    "IdentificationMonth"  	 int4              	 NULL,
    "IdentificationYear"  	 int4              	 NULL,
    "IdentificationDateSupplement"  	 varchar( 255 )     	 NULL,
    "VernacularName"  	 varchar( 255 )     	 NULL,
    "TaxonomicName"  	 varchar( 255 )     	 NULL,
    "NomID"  	 int4              	 NULL DEFAULT 0,
    "IdentificationCategory"  	 varchar( 255 )     	 NULL,
    "IdentificationQualifier"  	 varchar( 10 )     	 NULL,
    "IsLastName"  	 bool              	 NULL,
    "LiteratureUsed"  	 varchar( 255 )     	 NULL,
    "Responsible"  	 varchar( 255 )     	 NULL,
    "Notes"  	 varchar( 255 )     	 NULL,
    "IsExsiccataTaxon"  	 bool              	 NULL,
  PRIMARY KEY ( "IdentificationUnitID","CollectionSpecimenID","IdentificationSequence" )
 );




/*=== Table: IdentificationUnit ===*/
/* Organism that is present in or on a collection specimen. */
  /*   IdentificationUnitID: ID of the identification unit (usually an organism that is present on the collection specimen). */
  /*   CollectionSpecimenID: ID of the collection specimen on which the identification unit is present. */
  /*   TaxonomicGroup: Taxonomic group the belongs to e.g. (1) plant, (2) fungus, (3) lichen, (4) animal, (5) bacteria/procaryotic. */
  /*   OnlyObserved: This organism was only observed by the collector, i.e. it is not present on the specimen. */
  /*   TypeStatus: If identification unit is type of a taxonomic name: holotype, syntype, etc. */
  /*   TypifiedTaxon: Name of the taxonomic name typified by this identification unit. */
  /*   SubstrateAssociation: The IdentificationUnitID of the organism or substrate, where this organism is growing on (= foreign key). */
  /*   ColonisedPart: If a SubstrateAssociation exists: part of the substrate that is affected in the interaction (e.g. 'leaves'). */
  /*   LifeStage: e.g. II, III for spore generations of rusts or seed, seedling etc. for higher plants. */
  /*   Notes: Further information on the identification unit or interaction, e.g. symptoms of infection like 'gall'. */
CREATE TABLE "IdentificationUnit"
 ( 
    "IdentificationUnitID" SERIAL   NOT NULL,
    "CollectionSpecimenID"  	 int4              	 NOT NULL,
    "TaxonomicGroup"  	 int4              	 NOT NULL,
    "OnlyObserved"  	 bool              	 NOT NULL DEFAULT 'false',
    "TypeStatus"  	 varchar( 255 )     	 NULL,
    "TypifiedTaxon"  	 varchar( 255 )     	 NULL,
    "SubstrateAssociation"  	 int4              	 NULL,
    "ColonisedPart"  	 varchar( 255 )     	 NULL,
    "LifeStage"  	 varchar( 255 )     	 NULL,
    "Notes"  	 varchar( 255 )     	 NULL,
  PRIMARY KEY ( "IdentificationUnitID","CollectionSpecimenID" )
 );




/*=== Table: LocalisationSystem ===*/
/* Localisation system used for the determination of the geographical data. */
  /*   LocalisationSystemID: Unique reference ID for localisation system (= primary key). */
  /*   LocalisationSystemName: Name of the system used for the determination of the place of the collection, e. g. Gauss-Krger, MTB, GIS. */
  /*   LocalisationSystemTypeID: Refers to ID of CoordinateSystem (= foreign key). */
  /*   InterfaceDefinitions: User interface definition: locked status, label captions, etc. displayed in the form CollectionLocality. */
  /*   Description: Despription of the localisation method. */
  /*   MeasurementUnit: Unit used within the localisation system, e.g. m, miles etc. */
  /*   AccuracyOfLocalisation: The accuracy of values that can be reached with this method. */
  /*   ParsingMethod: Method for parsing the values typed in the fields [Location1, -2] in table [CollectionGeography] */
  /*   Enabled: Specifies if this item is enabled to be used within the database. */
CREATE TABLE "LocalisationSystem"
 ( 
    "LocalisationSystemID"  	 int4              	 NOT NULL PRIMARY KEY,
    "LocalisationSystemName"  	 varchar( 255 )     	 NOT NULL,
    "LocalisationSystemTypeID"  	 int4              	 NULL,
    "InterfaceDefinitions"  	 varchar( 255 )     	 NULL,
    "Description"  	 varchar( 255 )     	 NULL,
    "MeasurementUnit"  	 varchar( 255 )     	 NULL,
    "AccuracyOfLocalisation"  	 varchar( 255 )     	 NULL,
    "ParsingMethod"  	 varchar( 255 )     	 NULL,
    "Enabled"  	 bool              	 NULL
 );




/*=== Table: LocalisationSystemType ===*/
/* Coordinate systems etc. used by the localisation systems. */
  /*   LocalisationSystemTypeID: Refers to ID of CollectionSpecimen (= foreign key). */
  /*   LocalisationSystemType: Type of the localisation system used, e. g. Greenich Coordinates. */
  /*   LocalisationSystemGroup: Group of the localisation system used, e.g. Coordinates. */
CREATE TABLE "LocalisationSystemType"
 ( 
    "LocalisationSystemTypeID"  	 int4              	 NOT NULL PRIMARY KEY,
    "LocalisationSystemType"  	 varchar( 255 )     	 NOT NULL,
    "LocalisationSystemGroup"  	 varchar( 255 )     	 NOT NULL
 );


ALTER TABLE "CollectingPerson" ADD 
  FOREIGN KEY ( "CollectionSpecimenID" ) REFERENCES "CollectionSpecimen" ( "CollectionSpecimenID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "CollectionDuplicate" ADD 
  FOREIGN KEY ( "CollectionSpecimenID" ) REFERENCES "CollectionSpecimen" ( "CollectionSpecimenID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "CollectionGeography" ADD 
  FOREIGN KEY ( "CollectionSpecimenID" ) REFERENCES "CollectionSpecimen" ( "CollectionSpecimenID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "CollectionGeography" ADD 
  FOREIGN KEY ( "LocalisationSystemID" ) REFERENCES "LocalisationSystem" ( "LocalisationSystemID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "CollectionImage" ADD 
  FOREIGN KEY ( "CollectionSpecimenID" ) REFERENCES "CollectionSpecimen" ( "CollectionSpecimenID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "CollectionMaterial" ADD 
  FOREIGN KEY ( "CollectionSpecimenID" ) REFERENCES "CollectionSpecimen" ( "CollectionSpecimenID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "CollectionProject" ADD 
  FOREIGN KEY ( "CollectionSpecimenID" ) REFERENCES "CollectionSpecimen" ( "CollectionSpecimenID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "Identification" ADD 
  FOREIGN KEY ( "IdentificationUnitID", "CollectionSpecimenID" ) REFERENCES "IdentificationUnit" ( "IdentificationUnitID", "CollectionSpecimenID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "IdentificationUnit" ADD 
  FOREIGN KEY ( "CollectionSpecimenID" ) REFERENCES "CollectionSpecimen" ( "CollectionSpecimenID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
ALTER TABLE "LocalisationSystem" ADD 
  FOREIGN KEY ( "LocalisationSystemTypeID" ) REFERENCES "LocalisationSystemType" ( "LocalisationSystemTypeID" ) ON UPDATE CASCADE ON DELETE CASCADE
;
